@@ -1,4 +1,7 @@
-#! /usr/bin/python
+#!/usr/bin/env python
+
+# Copyright (c) 2009 Twisted Matrix Laboratories.
+# See LICENSE for details.
 
 from twisted.spread import pb
 from twisted.internet import reactor
@@ -22,7 +25,7 @@ class One(pb.Root):
         raise MyError2(msg)
 
 def main():
-    reactor.listenTCP(8800, pb.BrokerFactory(One()))
+    reactor.listenTCP(8800, pb.PBServerFactory(One()))
     reactor.run()
 
 if __name__ == '__main__':
