@@ -1,25 +1,13 @@
 # -*- test-case-name: twisted.test.test_formmethod -*-
-# Twisted, the Framework of Your Internet
-# Copyright (C) 2001 Matthew W. Lefkowitz
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of version 2.1 of the GNU Lesser General Public
-# License as published by the Free Software Foundation.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Copyright (c) 2001-2004 Twisted Matrix Laboratories.
+# See LICENSE for details.
+
 
 """
 Form-based method objects.
 
 This module contains support for descriptive method signatures that can be used
-to format methods.  Currently this is only used by woven.
+to format methods.
 """
 
 import calendar
@@ -166,7 +154,7 @@ class IntegerRange(Integer):
         if self.allowNone and result == None:
             return result
         if result < self.min:
-            raise InputError, "Value %s is too small, is should be at least %s" % (result, self.min)
+            raise InputError, "Value %s is too small, it should be at least %s" % (result, self.min)
         if result > self.max:
             raise InputError, "Value %s is too large, it should be at most %s" % (result, self.max)
         return result
